const path = require('path');
const TypescriptPlugin = ({ tsLoaderOptions }, context) => ({
    name: 'vuepress-plugin-typescript',
    /**
     * Detect enhanceApp.ts
     */
    enhanceAppFiles() {
        const { sourceDir, themeAPI } = context;
        const enhanceAppPath = path.resolve(sourceDir, '.vuepress/enhanceApp.ts');
        const files = [enhanceAppPath];
        if (themeAPI.existsParentTheme) {
            files.push(path.resolve(themeAPI.parentTheme.path, 'enhanceApp.ts'));
        }
        const themeEnhanceAppPath = path.resolve(themeAPI.theme.path, 'enhanceApp.ts');
        files.push(themeEnhanceAppPath);
        return files;
    },
    /**
     * Allow following files support typescript:
     * - .ts
     * - .vue
     * - .md
     */
    chainWebpack(config) {
        config.module
            .rule('ts')
            .test(/\.ts$/)
            .use('ts-loader')
            .loader('ts-loader')
            .options(Object.assign({ appendTsSuffixTo: [/\.vue$/, /\.md$/], compilerOptions: {
                declaration: false,
            } }, tsLoaderOptions));
    },
});
module.exports = TypescriptPlugin;
//# sourceMappingURL=index.js.map